# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: crash_recovery orchestrator."""

from omniclaude.nodes.node_skill_crash_recovery_orchestrator.node import (
    NodeSkillCrashRecoveryOrchestrator,
)

__all__ = ["NodeSkillCrashRecoveryOrchestrator"]
