# SPDX-FileCopyrightText: 2025 OmniNode.ai Inc.
# SPDX-License-Identifier: MIT
"""Skill node: auto_merge orchestrator."""

from omniclaude.nodes.node_skill_auto_merge_orchestrator.node import (
    NodeSkillAutoMergeOrchestrator,
)

__all__ = ["NodeSkillAutoMergeOrchestrator"]
